EXPORTS
	?CancelDataAvailable@RPipe@@QAEHXZ @ 1 NONAME ; public: int __thiscall RPipe::CancelDataAvailable(void)
	?CancelSpaceAvailable@RPipe@@QAEHXZ @ 2 NONAME ; public: int __thiscall RPipe::CancelSpaceAvailable(void)
	?CancelWait@RPipe@@QAEXXZ @ 3 NONAME ; public: void __thiscall RPipe::CancelWait(void)
	?Close@RPipe@@QAEXXZ @ 4 NONAME ; public: void __thiscall RPipe::Close(void)
	?Create@RPipe@@SAHHAAV1@0W4TOwnerType@@1@Z @ 5 NONAME ; public: static int __cdecl RPipe::Create(int,class RPipe &,class RPipe &,enum TOwnerType,enum TOwnerType)
	?Define@RPipe@@SAHABVTDesC16@@H@Z @ 6 NONAME ; public: static int __cdecl RPipe::Define(class TDesC16 const &,int)
	?Define@RPipe@@SAHABVTDesC16@@HABVTSecurityPolicy@@@Z @ 7 NONAME ; public: static int __cdecl RPipe::Define(class TDesC16 const &,int,class TSecurityPolicy const &)
	?Destroy@RPipe@@SAHABVTDesC16@@@Z @ 8 NONAME ; public: static int __cdecl RPipe::Destroy(class TDesC16 const &)
	?Flush@RPipe@@QAEXXZ @ 9 NONAME ; public: void __thiscall RPipe::Flush(void)
	?HandleType@RPipe@@QBEHXZ @ 10 NONAME ; public: int __thiscall RPipe::HandleType(void)const 
	?Init@RPipe@@SAHXZ @ 11 NONAME ; public: static int __cdecl RPipe::Init(void)
	?MaxSize@RPipe@@QAEHXZ @ 12 NONAME ; public: int __thiscall RPipe::MaxSize(void)
	?NotifyDataAvailable@RPipe@@QAEXAAVTRequestStatus@@@Z @ 13 NONAME ; public: void __thiscall RPipe::NotifyDataAvailable(class TRequestStatus &)
	?NotifySpaceAvailable@RPipe@@QAEXHAAVTRequestStatus@@@Z @ 14 NONAME ; public: void __thiscall RPipe::NotifySpaceAvailable(int,class TRequestStatus &)
	?Open@RPipe@@QAEHABVTDesC16@@W4TMode@1@@Z @ 15 NONAME ; public: int __thiscall RPipe::Open(class TDesC16 const &,enum RPipe::TMode)
	?Open@RPipe@@QAEHHW4TOwnerType@@@Z @ 16 NONAME ; public: int __thiscall RPipe::Open(int,enum TOwnerType)
	?Open@RPipe@@QAEHVRMessagePtr2@@HW4TOwnerType@@@Z @ 17 NONAME ; public: int __thiscall RPipe::Open(class RMessagePtr2,int,enum TOwnerType)
	?Read@RPipe@@QAEHAAVTDes8@@H@Z @ 18 NONAME ; public: int __thiscall RPipe::Read(class TDes8 &,int)
	?ReadBlocking@RPipe@@QAEHAAVTDes8@@H@Z @ 19 NONAME ; public: int __thiscall RPipe::ReadBlocking(class TDes8 &,int)
	?Size@RPipe@@QAEHXZ @ 20 NONAME ; public: int __thiscall RPipe::Size(void)
	?Wait@RPipe@@QAEXABVTDesC16@@AAVTRequestStatus@@@Z @ 21 NONAME ; public: void __thiscall RPipe::Wait(class TDesC16 const &,class TRequestStatus &)
	?Write@RPipe@@QAEHABVTDesC8@@H@Z @ 22 NONAME ; public: int __thiscall RPipe::Write(class TDesC8 const &,int)
	?WriteBlocking@RPipe@@QAEHABVTDesC8@@H@Z @ 23 NONAME ; public: int __thiscall RPipe::WriteBlocking(class TDesC8 const &,int)
	?WaitForReader@RPipe@@QAEXABVTDesC16@@AAVTRequestStatus@@@Z @ 24 NONAME ; public: void __thiscall RPipe::WaitForReader(class TDesC16 const &,class TRequestStatus &)
	?WaitForWriter@RPipe@@QAEXABVTDesC16@@AAVTRequestStatus@@@Z @ 25 NONAME ; public: void __thiscall RPipe::WaitForWriter(class TDesC16 const &,class TRequestStatus &)

